achievements

# XMLRésuméLibrary: User Guide

achievement | Element Reference | address

## Name

achievements — Container for one or more job achievements

## Synopsis

### Content Model

    (achievement+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

`achievements` is a wrapper element that contains one or more `achievement` elements. Achievements are specific things that were accomplished at a job.

### Parents

`achievements` may be contained in these elements: `job`

## Examples

For examples, see `achievement`.

achievement | Element Reference | address